@@ -15,6 +15,10 @@ Chart::OFC2::Bar - OFC2 bar chart
         'x_axis' => Chart::OFC2::XAxis->new(
             'labels' => [ 'Jan', 'Feb', 'Mar', 'Apr', 'May' ],
         ),
+        'y_axis' => {
+            'max' => 'a',
+            'min' => 'a',
+        },
     );
     
     my $bar = Chart::OFC2::Bar->new();
@@ -30,6 +34,7 @@ Chart::OFC2::Bar - OFC2 bar chart
 =cut
 
 use Moose;
+use MooseX::StrictConstructor;
 
 our $VERSION = '0.01';
 
@@ -38,7 +43,6 @@ extends 'Chart::OFC2::BarLineBase';
 =head1 PROPERTIES
 
 	has '+type_name' => (default => 'bar');
-	has 'alpha'      => (is => 'rw', isa => 'Num',);
 
 =cut
 
@@ -56,6 +60,7 @@ has '+type_name' => (default => 'bar');
 
 package Chart::OFC2::Bar::3D;
 use Moose;
+use MooseX::StrictConstructor;
 our $VERSION = '0.01';
 extends 'Chart::OFC2::Bar';
 
@@ -80,6 +85,7 @@ Fade bar chart
 
 package Chart::OFC2::Bar::Fade;
 use Moose;
+use MooseX::StrictConstructor;
 our $VERSION = '0.01';
 extends 'Chart::OFC2::Bar';
 
@@ -104,6 +110,7 @@ Glass bar chart
 
 package Chart::OFC2::Bar::Glass;
 use Moose;
+use MooseX::StrictConstructor;
 our $VERSION = '0.01';
 extends 'Chart::OFC2::Bar';
 
@@ -128,6 +135,7 @@ Sketch bar chart
 
 package Chart::OFC2::Bar::Sketch;
 use Moose;
+use MooseX::StrictConstructor;
 our $VERSION = '0.01';
 extends 'Chart::OFC2::Bar';
 
@@ -152,6 +160,7 @@ Filled bar chart
 
 package Chart::OFC2::Bar::Filled;
 use Moose;
+use MooseX::StrictConstructor;
 our $VERSION = '0.01';
 extends 'Chart::OFC2::Bar';
 
@@ -179,6 +188,7 @@ Stack bar chart
 
 package Chart::OFC2::Bar::Stack;
 use Moose;
+use MooseX::StrictConstructor;
 our $VERSION = '0.01';
 extends 'Chart::OFC2::Bar';
 
