@@ -29,11 +29,11 @@ use MooseX::StrictConstructor;
 
 our $VERSION = '0.01';
 
-subtype 'Chart-OFC2-Labels'
+subtype 'Chart.OFC2.Labels'
     => as 'Object'
     => where { $_[0]->isa('Chart::OFC2::Labels') };
 
-coerce 'Chart-OFC2-Labels'
+coerce 'Chart.OFC2.Labels'
     => from 'ArrayRef'
     => via { Chart::OFC2::Labels->new('labels' => $_) };
 
