@@ -30,10 +30,10 @@ use MooseX::StrictConstructor;
 
 our $VERSION = '0.01';
 
-subtype 'Chart-OFC2-Title'
+subtype 'Chart.OFC2.Title'
     => as 'Object'
     => where { $_[0]->isa('Chart::OFC2::Title') };
-coerce 'Chart-OFC2-Title'
+coerce 'Chart.OFC2.Title'
     => from 'Str'
     => via { Chart::OFC2::Title->new('text' => $_) };
 
